# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from wallet.rpc import rpc_pb2 as wallet_dot_rpc_dot_rpc__pb2


class RPCServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.NewAddress = channel.unary_unary(
                '/wallet.rpc.RPCService/NewAddress',
                request_serializer=wallet_dot_rpc_dot_rpc__pb2.NewAddressRequest.SerializeToString,
                response_deserializer=wallet_dot_rpc_dot_rpc__pb2.NewAddressResponse.FromString,
                )
        self.List = channel.unary_unary(
                '/wallet.rpc.RPCService/List',
                request_serializer=wallet_dot_rpc_dot_rpc__pb2.ListRequest.SerializeToString,
                response_deserializer=wallet_dot_rpc_dot_rpc__pb2.ListResponse.FromString,
                )
        self.Balance = channel.unary_unary(
                '/wallet.rpc.RPCService/Balance',
                request_serializer=wallet_dot_rpc_dot_rpc__pb2.BalanceRequest.SerializeToString,
                response_deserializer=wallet_dot_rpc_dot_rpc__pb2.BalanceResponse.FromString,
                )
        self.SendFil = channel.unary_unary(
                '/wallet.rpc.RPCService/SendFil',
                request_serializer=wallet_dot_rpc_dot_rpc__pb2.SendFilRequest.SerializeToString,
                response_deserializer=wallet_dot_rpc_dot_rpc__pb2.SendFilResponse.FromString,
                )


class RPCServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def NewAddress(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Balance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendFil(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RPCServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'NewAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.NewAddress,
                    request_deserializer=wallet_dot_rpc_dot_rpc__pb2.NewAddressRequest.FromString,
                    response_serializer=wallet_dot_rpc_dot_rpc__pb2.NewAddressResponse.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=wallet_dot_rpc_dot_rpc__pb2.ListRequest.FromString,
                    response_serializer=wallet_dot_rpc_dot_rpc__pb2.ListResponse.SerializeToString,
            ),
            'Balance': grpc.unary_unary_rpc_method_handler(
                    servicer.Balance,
                    request_deserializer=wallet_dot_rpc_dot_rpc__pb2.BalanceRequest.FromString,
                    response_serializer=wallet_dot_rpc_dot_rpc__pb2.BalanceResponse.SerializeToString,
            ),
            'SendFil': grpc.unary_unary_rpc_method_handler(
                    servicer.SendFil,
                    request_deserializer=wallet_dot_rpc_dot_rpc__pb2.SendFilRequest.FromString,
                    response_serializer=wallet_dot_rpc_dot_rpc__pb2.SendFilResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'wallet.rpc.RPCService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RPCService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def NewAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/wallet.rpc.RPCService/NewAddress',
            wallet_dot_rpc_dot_rpc__pb2.NewAddressRequest.SerializeToString,
            wallet_dot_rpc_dot_rpc__pb2.NewAddressResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/wallet.rpc.RPCService/List',
            wallet_dot_rpc_dot_rpc__pb2.ListRequest.SerializeToString,
            wallet_dot_rpc_dot_rpc__pb2.ListResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Balance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/wallet.rpc.RPCService/Balance',
            wallet_dot_rpc_dot_rpc__pb2.BalanceRequest.SerializeToString,
            wallet_dot_rpc_dot_rpc__pb2.BalanceResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendFil(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/wallet.rpc.RPCService/SendFil',
            wallet_dot_rpc_dot_rpc__pb2.SendFilRequest.SerializeToString,
            wallet_dot_rpc_dot_rpc__pb2.SendFilResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: reputation/rpc/rpc.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='reputation/rpc/rpc.proto',
  package='reputation.rpc',
  syntax='proto3',
  serialized_options=b'Z-github.com/textileio/powergate/reputation/rpc',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18reputation/rpc/rpc.proto\x12\x0ereputation.rpc\")\n\nMinerScore\x12\x0c\n\x04\x61\x64\x64r\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x05\"-\n\x10\x41\x64\x64SourceRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05maddr\x18\x02 \x01(\t\"\x13\n\x11\x41\x64\x64SourceResponse\"$\n\x13GetTopMinersRequest\x12\r\n\x05limit\x18\x01 \x01(\x05\"F\n\x14GetTopMinersResponse\x12.\n\ntop_miners\x18\x01 \x03(\x0b\x32\x1a.reputation.rpc.MinerScore2\xbd\x01\n\nRPCService\x12R\n\tAddSource\x12 .reputation.rpc.AddSourceRequest\x1a!.reputation.rpc.AddSourceResponse\"\x00\x12[\n\x0cGetTopMiners\x12#.reputation.rpc.GetTopMinersRequest\x1a$.reputation.rpc.GetTopMinersResponse\"\x00\x42/Z-github.com/textileio/powergate/reputation/rpcb\x06proto3'
)




_MINERSCORE = _descriptor.Descriptor(
  name='MinerScore',
  full_name='reputation.rpc.MinerScore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addr', full_name='reputation.rpc.MinerScore.addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='reputation.rpc.MinerScore.score', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44,
  serialized_end=85,
)


_ADDSOURCEREQUEST = _descriptor.Descriptor(
  name='AddSourceRequest',
  full_name='reputation.rpc.AddSourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='reputation.rpc.AddSourceRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maddr', full_name='reputation.rpc.AddSourceRequest.maddr', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=132,
)


_ADDSOURCERESPONSE = _descriptor.Descriptor(
  name='AddSourceResponse',
  full_name='reputation.rpc.AddSourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=153,
)


_GETTOPMINERSREQUEST = _descriptor.Descriptor(
  name='GetTopMinersRequest',
  full_name='reputation.rpc.GetTopMinersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='limit', full_name='reputation.rpc.GetTopMinersRequest.limit', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=191,
)


_GETTOPMINERSRESPONSE = _descriptor.Descriptor(
  name='GetTopMinersResponse',
  full_name='reputation.rpc.GetTopMinersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='top_miners', full_name='reputation.rpc.GetTopMinersResponse.top_miners', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=263,
)

_GETTOPMINERSRESPONSE.fields_by_name['top_miners'].message_type = _MINERSCORE
DESCRIPTOR.message_types_by_name['MinerScore'] = _MINERSCORE
DESCRIPTOR.message_types_by_name['AddSourceRequest'] = _ADDSOURCEREQUEST
DESCRIPTOR.message_types_by_name['AddSourceResponse'] = _ADDSOURCERESPONSE
DESCRIPTOR.message_types_by_name['GetTopMinersRequest'] = _GETTOPMINERSREQUEST
DESCRIPTOR.message_types_by_name['GetTopMinersResponse'] = _GETTOPMINERSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MinerScore = _reflection.GeneratedProtocolMessageType('MinerScore', (_message.Message,), {
  'DESCRIPTOR' : _MINERSCORE,
  '__module__' : 'reputation.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:reputation.rpc.MinerScore)
  })
_sym_db.RegisterMessage(MinerScore)

AddSourceRequest = _reflection.GeneratedProtocolMessageType('AddSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDSOURCEREQUEST,
  '__module__' : 'reputation.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:reputation.rpc.AddSourceRequest)
  })
_sym_db.RegisterMessage(AddSourceRequest)

AddSourceResponse = _reflection.GeneratedProtocolMessageType('AddSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDSOURCERESPONSE,
  '__module__' : 'reputation.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:reputation.rpc.AddSourceResponse)
  })
_sym_db.RegisterMessage(AddSourceResponse)

GetTopMinersRequest = _reflection.GeneratedProtocolMessageType('GetTopMinersRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTOPMINERSREQUEST,
  '__module__' : 'reputation.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:reputation.rpc.GetTopMinersRequest)
  })
_sym_db.RegisterMessage(GetTopMinersRequest)

GetTopMinersResponse = _reflection.GeneratedProtocolMessageType('GetTopMinersResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTOPMINERSRESPONSE,
  '__module__' : 'reputation.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:reputation.rpc.GetTopMinersResponse)
  })
_sym_db.RegisterMessage(GetTopMinersResponse)


DESCRIPTOR._options = None

_RPCSERVICE = _descriptor.ServiceDescriptor(
  name='RPCService',
  full_name='reputation.rpc.RPCService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=266,
  serialized_end=455,
  methods=[
  _descriptor.MethodDescriptor(
    name='AddSource',
    full_name='reputation.rpc.RPCService.AddSource',
    index=0,
    containing_service=None,
    input_type=_ADDSOURCEREQUEST,
    output_type=_ADDSOURCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTopMiners',
    full_name='reputation.rpc.RPCService.GetTopMiners',
    index=1,
    containing_service=None,
    input_type=_GETTOPMINERSREQUEST,
    output_type=_GETTOPMINERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RPCSERVICE)

DESCRIPTOR.services_by_name['RPCService'] = _RPCSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: index/faults/rpc/rpc.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='index/faults/rpc/rpc.proto',
  package='index.faults.rpc',
  syntax='proto3',
  serialized_options=b'Z/github.com/textileio/powergate/index/faults/rpc',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1aindex/faults/rpc/rpc.proto\x12\x10index.faults.rpc\"\x98\x01\n\x05Index\x12\x11\n\ttipsetkey\x18\x01 \x01(\t\x12\x33\n\x06miners\x18\x02 \x03(\x0b\x32#.index.faults.rpc.Index.MinersEntry\x1aG\n\x0bMinersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.index.faults.rpc.Faults:\x02\x38\x01\"\x18\n\x06\x46\x61ults\x12\x0e\n\x06\x65pochs\x18\x01 \x03(\x03\"\x0c\n\nGetRequest\"5\n\x0bGetResponse\x12&\n\x05index\x18\x01 \x01(\x0b\x32\x17.index.faults.rpc.Index2R\n\nRPCService\x12\x44\n\x03Get\x12\x1c.index.faults.rpc.GetRequest\x1a\x1d.index.faults.rpc.GetResponse\"\x00\x42\x31Z/github.com/textileio/powergate/index/faults/rpcb\x06proto3'
)




_INDEX_MINERSENTRY = _descriptor.Descriptor(
  name='MinersEntry',
  full_name='index.faults.rpc.Index.MinersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='index.faults.rpc.Index.MinersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='index.faults.rpc.Index.MinersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=201,
)

_INDEX = _descriptor.Descriptor(
  name='Index',
  full_name='index.faults.rpc.Index',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tipsetkey', full_name='index.faults.rpc.Index.tipsetkey', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='miners', full_name='index.faults.rpc.Index.miners', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_INDEX_MINERSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=201,
)


_FAULTS = _descriptor.Descriptor(
  name='Faults',
  full_name='index.faults.rpc.Faults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='epochs', full_name='index.faults.rpc.Faults.epochs', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=227,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='index.faults.rpc.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=229,
  serialized_end=241,
)


_GETRESPONSE = _descriptor.Descriptor(
  name='GetResponse',
  full_name='index.faults.rpc.GetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='index.faults.rpc.GetResponse.index', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=296,
)

_INDEX_MINERSENTRY.fields_by_name['value'].message_type = _FAULTS
_INDEX_MINERSENTRY.containing_type = _INDEX
_INDEX.fields_by_name['miners'].message_type = _INDEX_MINERSENTRY
_GETRESPONSE.fields_by_name['index'].message_type = _INDEX
DESCRIPTOR.message_types_by_name['Index'] = _INDEX
DESCRIPTOR.message_types_by_name['Faults'] = _FAULTS
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetResponse'] = _GETRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Index = _reflection.GeneratedProtocolMessageType('Index', (_message.Message,), {

  'MinersEntry' : _reflection.GeneratedProtocolMessageType('MinersEntry', (_message.Message,), {
    'DESCRIPTOR' : _INDEX_MINERSENTRY,
    '__module__' : 'index.faults.rpc.rpc_pb2'
    # @@protoc_insertion_point(class_scope:index.faults.rpc.Index.MinersEntry)
    })
  ,
  'DESCRIPTOR' : _INDEX,
  '__module__' : 'index.faults.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.faults.rpc.Index)
  })
_sym_db.RegisterMessage(Index)
_sym_db.RegisterMessage(Index.MinersEntry)

Faults = _reflection.GeneratedProtocolMessageType('Faults', (_message.Message,), {
  'DESCRIPTOR' : _FAULTS,
  '__module__' : 'index.faults.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.faults.rpc.Faults)
  })
_sym_db.RegisterMessage(Faults)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREQUEST,
  '__module__' : 'index.faults.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.faults.rpc.GetRequest)
  })
_sym_db.RegisterMessage(GetRequest)

GetResponse = _reflection.GeneratedProtocolMessageType('GetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRESPONSE,
  '__module__' : 'index.faults.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.faults.rpc.GetResponse)
  })
_sym_db.RegisterMessage(GetResponse)


DESCRIPTOR._options = None
_INDEX_MINERSENTRY._options = None

_RPCSERVICE = _descriptor.ServiceDescriptor(
  name='RPCService',
  full_name='index.faults.rpc.RPCService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=298,
  serialized_end=380,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='index.faults.rpc.RPCService.Get',
    index=0,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RPCSERVICE)

DESCRIPTOR.services_by_name['RPCService'] = _RPCSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from reputation.rpc import rpc_pb2 as reputation_dot_rpc_dot_rpc__pb2


class RPCServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddSource = channel.unary_unary(
                '/reputation.rpc.RPCService/AddSource',
                request_serializer=reputation_dot_rpc_dot_rpc__pb2.AddSourceRequest.SerializeToString,
                response_deserializer=reputation_dot_rpc_dot_rpc__pb2.AddSourceResponse.FromString,
                )
        self.GetTopMiners = channel.unary_unary(
                '/reputation.rpc.RPCService/GetTopMiners',
                request_serializer=reputation_dot_rpc_dot_rpc__pb2.GetTopMinersRequest.SerializeToString,
                response_deserializer=reputation_dot_rpc_dot_rpc__pb2.GetTopMinersResponse.FromString,
                )


class RPCServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def AddSource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTopMiners(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RPCServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AddSource': grpc.unary_unary_rpc_method_handler(
                    servicer.AddSource,
                    request_deserializer=reputation_dot_rpc_dot_rpc__pb2.AddSourceRequest.FromString,
                    response_serializer=reputation_dot_rpc_dot_rpc__pb2.AddSourceResponse.SerializeToString,
            ),
            'GetTopMiners': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTopMiners,
                    request_deserializer=reputation_dot_rpc_dot_rpc__pb2.GetTopMinersRequest.FromString,
                    response_serializer=reputation_dot_rpc_dot_rpc__pb2.GetTopMinersResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'reputation.rpc.RPCService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RPCService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def AddSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reputation.rpc.RPCService/AddSource',
            reputation_dot_rpc_dot_rpc__pb2.AddSourceRequest.SerializeToString,
            reputation_dot_rpc_dot_rpc__pb2.AddSourceResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTopMiners(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reputation.rpc.RPCService/GetTopMiners',
            reputation_dot_rpc_dot_rpc__pb2.GetTopMinersRequest.SerializeToString,
            reputation_dot_rpc_dot_rpc__pb2.GetTopMinersResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ffs.rpc import rpc_pb2 as ffs_dot_rpc_dot_rpc__pb2


class RPCServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/ffs.rpc.RPCService/Create',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.CreateRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.CreateResponse.FromString,
                )
        self.ListAPI = channel.unary_unary(
                '/ffs.rpc.RPCService/ListAPI',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.ListAPIRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.ListAPIResponse.FromString,
                )
        self.ID = channel.unary_unary(
                '/ffs.rpc.RPCService/ID',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.IDRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.IDResponse.FromString,
                )
        self.Addrs = channel.unary_unary(
                '/ffs.rpc.RPCService/Addrs',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.AddrsRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.AddrsResponse.FromString,
                )
        self.DefaultStorageConfig = channel.unary_unary(
                '/ffs.rpc.RPCService/DefaultStorageConfig',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.DefaultStorageConfigRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.DefaultStorageConfigResponse.FromString,
                )
        self.NewAddr = channel.unary_unary(
                '/ffs.rpc.RPCService/NewAddr',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.NewAddrRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.NewAddrResponse.FromString,
                )
        self.GetStorageConfig = channel.unary_unary(
                '/ffs.rpc.RPCService/GetStorageConfig',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.GetStorageConfigRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.GetStorageConfigResponse.FromString,
                )
        self.SetDefaultStorageConfig = channel.unary_unary(
                '/ffs.rpc.RPCService/SetDefaultStorageConfig',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.SetDefaultStorageConfigRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.SetDefaultStorageConfigResponse.FromString,
                )
        self.Show = channel.unary_unary(
                '/ffs.rpc.RPCService/Show',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.ShowRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.ShowResponse.FromString,
                )
        self.Info = channel.unary_unary(
                '/ffs.rpc.RPCService/Info',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.InfoRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.InfoResponse.FromString,
                )
        self.CancelJob = channel.unary_unary(
                '/ffs.rpc.RPCService/CancelJob',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.CancelJobRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.CancelJobResponse.FromString,
                )
        self.WatchJobs = channel.unary_stream(
                '/ffs.rpc.RPCService/WatchJobs',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.WatchJobsRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.WatchJobsResponse.FromString,
                )
        self.WatchLogs = channel.unary_stream(
                '/ffs.rpc.RPCService/WatchLogs',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.WatchLogsRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.WatchLogsResponse.FromString,
                )
        self.Replace = channel.unary_unary(
                '/ffs.rpc.RPCService/Replace',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.ReplaceRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.ReplaceResponse.FromString,
                )
        self.PushStorageConfig = channel.unary_unary(
                '/ffs.rpc.RPCService/PushStorageConfig',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.PushStorageConfigRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.PushStorageConfigResponse.FromString,
                )
        self.Remove = channel.unary_unary(
                '/ffs.rpc.RPCService/Remove',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.RemoveRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.RemoveResponse.FromString,
                )
        self.Get = channel.unary_stream(
                '/ffs.rpc.RPCService/Get',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.GetRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.GetResponse.FromString,
                )
        self.SendFil = channel.unary_unary(
                '/ffs.rpc.RPCService/SendFil',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.SendFilRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.SendFilResponse.FromString,
                )
        self.Close = channel.unary_unary(
                '/ffs.rpc.RPCService/Close',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.CloseRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.CloseResponse.FromString,
                )
        self.Stage = channel.stream_unary(
                '/ffs.rpc.RPCService/Stage',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.StageRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.StageResponse.FromString,
                )
        self.ListPayChannels = channel.unary_unary(
                '/ffs.rpc.RPCService/ListPayChannels',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.ListPayChannelsRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.ListPayChannelsResponse.FromString,
                )
        self.CreatePayChannel = channel.unary_unary(
                '/ffs.rpc.RPCService/CreatePayChannel',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.CreatePayChannelRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.CreatePayChannelResponse.FromString,
                )
        self.RedeemPayChannel = channel.unary_unary(
                '/ffs.rpc.RPCService/RedeemPayChannel',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.RedeemPayChannelRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.RedeemPayChannelResponse.FromString,
                )
        self.ListStorageDealRecords = channel.unary_unary(
                '/ffs.rpc.RPCService/ListStorageDealRecords',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.ListStorageDealRecordsRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.ListStorageDealRecordsResponse.FromString,
                )
        self.ListRetrievalDealRecords = channel.unary_unary(
                '/ffs.rpc.RPCService/ListRetrievalDealRecords',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.ListRetrievalDealRecordsRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.ListRetrievalDealRecordsResponse.FromString,
                )
        self.ShowAll = channel.unary_unary(
                '/ffs.rpc.RPCService/ShowAll',
                request_serializer=ffs_dot_rpc_dot_rpc__pb2.ShowAllRequest.SerializeToString,
                response_deserializer=ffs_dot_rpc_dot_rpc__pb2.ShowAllResponse.FromString,
                )


class RPCServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Admin
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAPI(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ID(self, request, context):
        """Instance
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Addrs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DefaultStorageConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NewAddr(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStorageConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDefaultStorageConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Show(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Info(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchJobs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchLogs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Replace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PushStorageConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Remove(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendFil(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Close(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stage(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPayChannels(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePayChannel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RedeemPayChannel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListStorageDealRecords(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRetrievalDealRecords(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ShowAll(self, request, context):
        """UI support
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RPCServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.CreateRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.CreateResponse.SerializeToString,
            ),
            'ListAPI': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAPI,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.ListAPIRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.ListAPIResponse.SerializeToString,
            ),
            'ID': grpc.unary_unary_rpc_method_handler(
                    servicer.ID,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.IDRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.IDResponse.SerializeToString,
            ),
            'Addrs': grpc.unary_unary_rpc_method_handler(
                    servicer.Addrs,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.AddrsRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.AddrsResponse.SerializeToString,
            ),
            'DefaultStorageConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.DefaultStorageConfig,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.DefaultStorageConfigRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.DefaultStorageConfigResponse.SerializeToString,
            ),
            'NewAddr': grpc.unary_unary_rpc_method_handler(
                    servicer.NewAddr,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.NewAddrRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.NewAddrResponse.SerializeToString,
            ),
            'GetStorageConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStorageConfig,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.GetStorageConfigRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.GetStorageConfigResponse.SerializeToString,
            ),
            'SetDefaultStorageConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDefaultStorageConfig,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.SetDefaultStorageConfigRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.SetDefaultStorageConfigResponse.SerializeToString,
            ),
            'Show': grpc.unary_unary_rpc_method_handler(
                    servicer.Show,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.ShowRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.ShowResponse.SerializeToString,
            ),
            'Info': grpc.unary_unary_rpc_method_handler(
                    servicer.Info,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.InfoRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.InfoResponse.SerializeToString,
            ),
            'CancelJob': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelJob,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.CancelJobRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.CancelJobResponse.SerializeToString,
            ),
            'WatchJobs': grpc.unary_stream_rpc_method_handler(
                    servicer.WatchJobs,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.WatchJobsRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.WatchJobsResponse.SerializeToString,
            ),
            'WatchLogs': grpc.unary_stream_rpc_method_handler(
                    servicer.WatchLogs,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.WatchLogsRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.WatchLogsResponse.SerializeToString,
            ),
            'Replace': grpc.unary_unary_rpc_method_handler(
                    servicer.Replace,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.ReplaceRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.ReplaceResponse.SerializeToString,
            ),
            'PushStorageConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.PushStorageConfig,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.PushStorageConfigRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.PushStorageConfigResponse.SerializeToString,
            ),
            'Remove': grpc.unary_unary_rpc_method_handler(
                    servicer.Remove,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.RemoveRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.RemoveResponse.SerializeToString,
            ),
            'Get': grpc.unary_stream_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.GetRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.GetResponse.SerializeToString,
            ),
            'SendFil': grpc.unary_unary_rpc_method_handler(
                    servicer.SendFil,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.SendFilRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.SendFilResponse.SerializeToString,
            ),
            'Close': grpc.unary_unary_rpc_method_handler(
                    servicer.Close,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.CloseRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.CloseResponse.SerializeToString,
            ),
            'Stage': grpc.stream_unary_rpc_method_handler(
                    servicer.Stage,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.StageRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.StageResponse.SerializeToString,
            ),
            'ListPayChannels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPayChannels,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.ListPayChannelsRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.ListPayChannelsResponse.SerializeToString,
            ),
            'CreatePayChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePayChannel,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.CreatePayChannelRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.CreatePayChannelResponse.SerializeToString,
            ),
            'RedeemPayChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.RedeemPayChannel,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.RedeemPayChannelRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.RedeemPayChannelResponse.SerializeToString,
            ),
            'ListStorageDealRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.ListStorageDealRecords,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.ListStorageDealRecordsRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.ListStorageDealRecordsResponse.SerializeToString,
            ),
            'ListRetrievalDealRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRetrievalDealRecords,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.ListRetrievalDealRecordsRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.ListRetrievalDealRecordsResponse.SerializeToString,
            ),
            'ShowAll': grpc.unary_unary_rpc_method_handler(
                    servicer.ShowAll,
                    request_deserializer=ffs_dot_rpc_dot_rpc__pb2.ShowAllRequest.FromString,
                    response_serializer=ffs_dot_rpc_dot_rpc__pb2.ShowAllResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ffs.rpc.RPCService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RPCService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/Create',
            ffs_dot_rpc_dot_rpc__pb2.CreateRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.CreateResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAPI(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/ListAPI',
            ffs_dot_rpc_dot_rpc__pb2.ListAPIRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.ListAPIResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/ID',
            ffs_dot_rpc_dot_rpc__pb2.IDRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.IDResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Addrs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/Addrs',
            ffs_dot_rpc_dot_rpc__pb2.AddrsRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.AddrsResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DefaultStorageConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/DefaultStorageConfig',
            ffs_dot_rpc_dot_rpc__pb2.DefaultStorageConfigRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.DefaultStorageConfigResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NewAddr(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/NewAddr',
            ffs_dot_rpc_dot_rpc__pb2.NewAddrRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.NewAddrResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetStorageConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/GetStorageConfig',
            ffs_dot_rpc_dot_rpc__pb2.GetStorageConfigRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.GetStorageConfigResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDefaultStorageConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/SetDefaultStorageConfig',
            ffs_dot_rpc_dot_rpc__pb2.SetDefaultStorageConfigRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.SetDefaultStorageConfigResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Show(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/Show',
            ffs_dot_rpc_dot_rpc__pb2.ShowRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.ShowResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Info(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/Info',
            ffs_dot_rpc_dot_rpc__pb2.InfoRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.InfoResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/CancelJob',
            ffs_dot_rpc_dot_rpc__pb2.CancelJobRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.CancelJobResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ffs.rpc.RPCService/WatchJobs',
            ffs_dot_rpc_dot_rpc__pb2.WatchJobsRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.WatchJobsResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ffs.rpc.RPCService/WatchLogs',
            ffs_dot_rpc_dot_rpc__pb2.WatchLogsRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.WatchLogsResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Replace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/Replace',
            ffs_dot_rpc_dot_rpc__pb2.ReplaceRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.ReplaceResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PushStorageConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/PushStorageConfig',
            ffs_dot_rpc_dot_rpc__pb2.PushStorageConfigRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.PushStorageConfigResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Remove(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/Remove',
            ffs_dot_rpc_dot_rpc__pb2.RemoveRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.RemoveResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ffs.rpc.RPCService/Get',
            ffs_dot_rpc_dot_rpc__pb2.GetRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.GetResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendFil(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/SendFil',
            ffs_dot_rpc_dot_rpc__pb2.SendFilRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.SendFilResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Close(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/Close',
            ffs_dot_rpc_dot_rpc__pb2.CloseRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.CloseResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Stage(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/ffs.rpc.RPCService/Stage',
            ffs_dot_rpc_dot_rpc__pb2.StageRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.StageResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPayChannels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/ListPayChannels',
            ffs_dot_rpc_dot_rpc__pb2.ListPayChannelsRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.ListPayChannelsResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePayChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/CreatePayChannel',
            ffs_dot_rpc_dot_rpc__pb2.CreatePayChannelRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.CreatePayChannelResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RedeemPayChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/RedeemPayChannel',
            ffs_dot_rpc_dot_rpc__pb2.RedeemPayChannelRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.RedeemPayChannelResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListStorageDealRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/ListStorageDealRecords',
            ffs_dot_rpc_dot_rpc__pb2.ListStorageDealRecordsRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.ListStorageDealRecordsResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRetrievalDealRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/ListRetrievalDealRecords',
            ffs_dot_rpc_dot_rpc__pb2.ListRetrievalDealRecordsRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.ListRetrievalDealRecordsResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ShowAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ffs.rpc.RPCService/ShowAll',
            ffs_dot_rpc_dot_rpc__pb2.ShowAllRequest.SerializeToString,
            ffs_dot_rpc_dot_rpc__pb2.ShowAllResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: wallet/rpc/rpc.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='wallet/rpc/rpc.proto',
  package='wallet.rpc',
  syntax='proto3',
  serialized_options=b'Z)github.com/textileio/powergate/wallet/rpc',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14wallet/rpc/rpc.proto\x12\nwallet.rpc\"!\n\x11NewAddressRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\"%\n\x12NewAddressResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"\x1b\n\x0bListRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\"!\n\x0cListResponse\x12\x11\n\taddresses\x18\x01 \x03(\t\"!\n\x0e\x42\x61lanceRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"\"\n\x0f\x42\x61lanceResponse\x12\x0f\n\x07\x62\x61lance\x18\x01 \x01(\x04\":\n\x0eSendFilRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\n\n\x02to\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x03\"\x11\n\x0fSendFilResponse2\xa4\x02\n\nRPCService\x12M\n\nNewAddress\x12\x1d.wallet.rpc.NewAddressRequest\x1a\x1e.wallet.rpc.NewAddressResponse\"\x00\x12;\n\x04List\x12\x17.wallet.rpc.ListRequest\x1a\x18.wallet.rpc.ListResponse\"\x00\x12\x44\n\x07\x42\x61lance\x12\x1a.wallet.rpc.BalanceRequest\x1a\x1b.wallet.rpc.BalanceResponse\"\x00\x12\x44\n\x07SendFil\x12\x1a.wallet.rpc.SendFilRequest\x1a\x1b.wallet.rpc.SendFilResponse\"\x00\x42+Z)github.com/textileio/powergate/wallet/rpcb\x06proto3'
)




_NEWADDRESSREQUEST = _descriptor.Descriptor(
  name='NewAddressRequest',
  full_name='wallet.rpc.NewAddressRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='wallet.rpc.NewAddressRequest.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=69,
)


_NEWADDRESSRESPONSE = _descriptor.Descriptor(
  name='NewAddressResponse',
  full_name='wallet.rpc.NewAddressResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='wallet.rpc.NewAddressResponse.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=108,
)


_LISTREQUEST = _descriptor.Descriptor(
  name='ListRequest',
  full_name='wallet.rpc.ListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='wallet.rpc.ListRequest.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=110,
  serialized_end=137,
)


_LISTRESPONSE = _descriptor.Descriptor(
  name='ListResponse',
  full_name='wallet.rpc.ListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addresses', full_name='wallet.rpc.ListResponse.addresses', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=172,
)


_BALANCEREQUEST = _descriptor.Descriptor(
  name='BalanceRequest',
  full_name='wallet.rpc.BalanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='wallet.rpc.BalanceRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=207,
)


_BALANCERESPONSE = _descriptor.Descriptor(
  name='BalanceResponse',
  full_name='wallet.rpc.BalanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='balance', full_name='wallet.rpc.BalanceResponse.balance', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=243,
)


_SENDFILREQUEST = _descriptor.Descriptor(
  name='SendFilRequest',
  full_name='wallet.rpc.SendFilRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from', full_name='wallet.rpc.SendFilRequest.from', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to', full_name='wallet.rpc.SendFilRequest.to', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='wallet.rpc.SendFilRequest.amount', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=303,
)


_SENDFILRESPONSE = _descriptor.Descriptor(
  name='SendFilResponse',
  full_name='wallet.rpc.SendFilResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=322,
)

DESCRIPTOR.message_types_by_name['NewAddressRequest'] = _NEWADDRESSREQUEST
DESCRIPTOR.message_types_by_name['NewAddressResponse'] = _NEWADDRESSRESPONSE
DESCRIPTOR.message_types_by_name['ListRequest'] = _LISTREQUEST
DESCRIPTOR.message_types_by_name['ListResponse'] = _LISTRESPONSE
DESCRIPTOR.message_types_by_name['BalanceRequest'] = _BALANCEREQUEST
DESCRIPTOR.message_types_by_name['BalanceResponse'] = _BALANCERESPONSE
DESCRIPTOR.message_types_by_name['SendFilRequest'] = _SENDFILREQUEST
DESCRIPTOR.message_types_by_name['SendFilResponse'] = _SENDFILRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NewAddressRequest = _reflection.GeneratedProtocolMessageType('NewAddressRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWADDRESSREQUEST,
  '__module__' : 'wallet.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:wallet.rpc.NewAddressRequest)
  })
_sym_db.RegisterMessage(NewAddressRequest)

NewAddressResponse = _reflection.GeneratedProtocolMessageType('NewAddressResponse', (_message.Message,), {
  'DESCRIPTOR' : _NEWADDRESSRESPONSE,
  '__module__' : 'wallet.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:wallet.rpc.NewAddressResponse)
  })
_sym_db.RegisterMessage(NewAddressResponse)

ListRequest = _reflection.GeneratedProtocolMessageType('ListRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTREQUEST,
  '__module__' : 'wallet.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:wallet.rpc.ListRequest)
  })
_sym_db.RegisterMessage(ListRequest)

ListResponse = _reflection.GeneratedProtocolMessageType('ListResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRESPONSE,
  '__module__' : 'wallet.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:wallet.rpc.ListResponse)
  })
_sym_db.RegisterMessage(ListResponse)

BalanceRequest = _reflection.GeneratedProtocolMessageType('BalanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _BALANCEREQUEST,
  '__module__' : 'wallet.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:wallet.rpc.BalanceRequest)
  })
_sym_db.RegisterMessage(BalanceRequest)

BalanceResponse = _reflection.GeneratedProtocolMessageType('BalanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _BALANCERESPONSE,
  '__module__' : 'wallet.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:wallet.rpc.BalanceResponse)
  })
_sym_db.RegisterMessage(BalanceResponse)

SendFilRequest = _reflection.GeneratedProtocolMessageType('SendFilRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDFILREQUEST,
  '__module__' : 'wallet.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:wallet.rpc.SendFilRequest)
  })
_sym_db.RegisterMessage(SendFilRequest)

SendFilResponse = _reflection.GeneratedProtocolMessageType('SendFilResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDFILRESPONSE,
  '__module__' : 'wallet.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:wallet.rpc.SendFilResponse)
  })
_sym_db.RegisterMessage(SendFilResponse)


DESCRIPTOR._options = None

_RPCSERVICE = _descriptor.ServiceDescriptor(
  name='RPCService',
  full_name='wallet.rpc.RPCService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=325,
  serialized_end=617,
  methods=[
  _descriptor.MethodDescriptor(
    name='NewAddress',
    full_name='wallet.rpc.RPCService.NewAddress',
    index=0,
    containing_service=None,
    input_type=_NEWADDRESSREQUEST,
    output_type=_NEWADDRESSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='wallet.rpc.RPCService.List',
    index=1,
    containing_service=None,
    input_type=_LISTREQUEST,
    output_type=_LISTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Balance',
    full_name='wallet.rpc.RPCService.Balance',
    index=2,
    containing_service=None,
    input_type=_BALANCEREQUEST,
    output_type=_BALANCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendFil',
    full_name='wallet.rpc.RPCService.SendFil',
    index=3,
    containing_service=None,
    input_type=_SENDFILREQUEST,
    output_type=_SENDFILRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RPCSERVICE)

DESCRIPTOR.services_by_name['RPCService'] = _RPCSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: health/rpc/rpc.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='health/rpc/rpc.proto',
  package='health.rpc',
  syntax='proto3',
  serialized_options=b'Z)github.com/textileio/powergate/health/rpc',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14health/rpc/rpc.proto\x12\nhealth.rpc\"\x0e\n\x0c\x43heckRequest\"E\n\rCheckResponse\x12\"\n\x06status\x18\x01 \x01(\x0e\x32\x12.health.rpc.Status\x12\x10\n\x08messages\x18\x02 \x03(\t*V\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\r\n\tSTATUS_OK\x10\x01\x12\x13\n\x0fSTATUS_DEGRADED\x10\x02\x12\x10\n\x0cSTATUS_ERROR\x10\x03\x32L\n\nRPCService\x12>\n\x05\x43heck\x12\x18.health.rpc.CheckRequest\x1a\x19.health.rpc.CheckResponse\"\x00\x42+Z)github.com/textileio/powergate/health/rpcb\x06proto3'
)

_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='health.rpc.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATUS_OK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATUS_DEGRADED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATUS_ERROR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=123,
  serialized_end=209,
)
_sym_db.RegisterEnumDescriptor(_STATUS)

Status = enum_type_wrapper.EnumTypeWrapper(_STATUS)
STATUS_UNSPECIFIED = 0
STATUS_OK = 1
STATUS_DEGRADED = 2
STATUS_ERROR = 3



_CHECKREQUEST = _descriptor.Descriptor(
  name='CheckRequest',
  full_name='health.rpc.CheckRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=50,
)


_CHECKRESPONSE = _descriptor.Descriptor(
  name='CheckResponse',
  full_name='health.rpc.CheckResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='health.rpc.CheckResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='health.rpc.CheckResponse.messages', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=121,
)

_CHECKRESPONSE.fields_by_name['status'].enum_type = _STATUS
DESCRIPTOR.message_types_by_name['CheckRequest'] = _CHECKREQUEST
DESCRIPTOR.message_types_by_name['CheckResponse'] = _CHECKRESPONSE
DESCRIPTOR.enum_types_by_name['Status'] = _STATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CheckRequest = _reflection.GeneratedProtocolMessageType('CheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHECKREQUEST,
  '__module__' : 'health.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:health.rpc.CheckRequest)
  })
_sym_db.RegisterMessage(CheckRequest)

CheckResponse = _reflection.GeneratedProtocolMessageType('CheckResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHECKRESPONSE,
  '__module__' : 'health.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:health.rpc.CheckResponse)
  })
_sym_db.RegisterMessage(CheckResponse)


DESCRIPTOR._options = None

_RPCSERVICE = _descriptor.ServiceDescriptor(
  name='RPCService',
  full_name='health.rpc.RPCService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=211,
  serialized_end=287,
  methods=[
  _descriptor.MethodDescriptor(
    name='Check',
    full_name='health.rpc.RPCService.Check',
    index=0,
    containing_service=None,
    input_type=_CHECKREQUEST,
    output_type=_CHECKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RPCSERVICE)

DESCRIPTOR.services_by_name['RPCService'] = _RPCSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from net.rpc import rpc_pb2 as net_dot_rpc_dot_rpc__pb2


class RPCServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListenAddr = channel.unary_unary(
                '/net.rpc.RPCService/ListenAddr',
                request_serializer=net_dot_rpc_dot_rpc__pb2.ListenAddrRequest.SerializeToString,
                response_deserializer=net_dot_rpc_dot_rpc__pb2.ListenAddrResponse.FromString,
                )
        self.Peers = channel.unary_unary(
                '/net.rpc.RPCService/Peers',
                request_serializer=net_dot_rpc_dot_rpc__pb2.PeersRequest.SerializeToString,
                response_deserializer=net_dot_rpc_dot_rpc__pb2.PeersResponse.FromString,
                )
        self.FindPeer = channel.unary_unary(
                '/net.rpc.RPCService/FindPeer',
                request_serializer=net_dot_rpc_dot_rpc__pb2.FindPeerRequest.SerializeToString,
                response_deserializer=net_dot_rpc_dot_rpc__pb2.FindPeerResponse.FromString,
                )
        self.ConnectPeer = channel.unary_unary(
                '/net.rpc.RPCService/ConnectPeer',
                request_serializer=net_dot_rpc_dot_rpc__pb2.ConnectPeerRequest.SerializeToString,
                response_deserializer=net_dot_rpc_dot_rpc__pb2.ConnectPeerResponse.FromString,
                )
        self.DisconnectPeer = channel.unary_unary(
                '/net.rpc.RPCService/DisconnectPeer',
                request_serializer=net_dot_rpc_dot_rpc__pb2.DisconnectPeerRequest.SerializeToString,
                response_deserializer=net_dot_rpc_dot_rpc__pb2.DisconnectPeerResponse.FromString,
                )
        self.Connectedness = channel.unary_unary(
                '/net.rpc.RPCService/Connectedness',
                request_serializer=net_dot_rpc_dot_rpc__pb2.ConnectednessRequest.SerializeToString,
                response_deserializer=net_dot_rpc_dot_rpc__pb2.ConnectednessResponse.FromString,
                )


class RPCServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListenAddr(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Peers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindPeer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConnectPeer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisconnectPeer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Connectedness(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RPCServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListenAddr': grpc.unary_unary_rpc_method_handler(
                    servicer.ListenAddr,
                    request_deserializer=net_dot_rpc_dot_rpc__pb2.ListenAddrRequest.FromString,
                    response_serializer=net_dot_rpc_dot_rpc__pb2.ListenAddrResponse.SerializeToString,
            ),
            'Peers': grpc.unary_unary_rpc_method_handler(
                    servicer.Peers,
                    request_deserializer=net_dot_rpc_dot_rpc__pb2.PeersRequest.FromString,
                    response_serializer=net_dot_rpc_dot_rpc__pb2.PeersResponse.SerializeToString,
            ),
            'FindPeer': grpc.unary_unary_rpc_method_handler(
                    servicer.FindPeer,
                    request_deserializer=net_dot_rpc_dot_rpc__pb2.FindPeerRequest.FromString,
                    response_serializer=net_dot_rpc_dot_rpc__pb2.FindPeerResponse.SerializeToString,
            ),
            'ConnectPeer': grpc.unary_unary_rpc_method_handler(
                    servicer.ConnectPeer,
                    request_deserializer=net_dot_rpc_dot_rpc__pb2.ConnectPeerRequest.FromString,
                    response_serializer=net_dot_rpc_dot_rpc__pb2.ConnectPeerResponse.SerializeToString,
            ),
            'DisconnectPeer': grpc.unary_unary_rpc_method_handler(
                    servicer.DisconnectPeer,
                    request_deserializer=net_dot_rpc_dot_rpc__pb2.DisconnectPeerRequest.FromString,
                    response_serializer=net_dot_rpc_dot_rpc__pb2.DisconnectPeerResponse.SerializeToString,
            ),
            'Connectedness': grpc.unary_unary_rpc_method_handler(
                    servicer.Connectedness,
                    request_deserializer=net_dot_rpc_dot_rpc__pb2.ConnectednessRequest.FromString,
                    response_serializer=net_dot_rpc_dot_rpc__pb2.ConnectednessResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'net.rpc.RPCService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RPCService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListenAddr(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/net.rpc.RPCService/ListenAddr',
            net_dot_rpc_dot_rpc__pb2.ListenAddrRequest.SerializeToString,
            net_dot_rpc_dot_rpc__pb2.ListenAddrResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Peers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/net.rpc.RPCService/Peers',
            net_dot_rpc_dot_rpc__pb2.PeersRequest.SerializeToString,
            net_dot_rpc_dot_rpc__pb2.PeersResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FindPeer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/net.rpc.RPCService/FindPeer',
            net_dot_rpc_dot_rpc__pb2.FindPeerRequest.SerializeToString,
            net_dot_rpc_dot_rpc__pb2.FindPeerResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConnectPeer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/net.rpc.RPCService/ConnectPeer',
            net_dot_rpc_dot_rpc__pb2.ConnectPeerRequest.SerializeToString,
            net_dot_rpc_dot_rpc__pb2.ConnectPeerResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisconnectPeer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/net.rpc.RPCService/DisconnectPeer',
            net_dot_rpc_dot_rpc__pb2.DisconnectPeerRequest.SerializeToString,
            net_dot_rpc_dot_rpc__pb2.DisconnectPeerResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Connectedness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/net.rpc.RPCService/Connectedness',
            net_dot_rpc_dot_rpc__pb2.ConnectednessRequest.SerializeToString,
            net_dot_rpc_dot_rpc__pb2.ConnectednessResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: index/ask/rpc/rpc.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='index/ask/rpc/rpc.proto',
  package='index.ask.rpc',
  syntax='proto3',
  serialized_options=b'Z,github.com/textileio/powergate/index/ask/rpc',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17index/ask/rpc/rpc.proto\x12\rindex.ask.rpc\"M\n\x05Query\x12\x11\n\tmax_price\x18\x01 \x01(\x04\x12\x12\n\npiece_size\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x0e\n\x06offset\x18\x04 \x01(\x05\"e\n\nStorageAsk\x12\r\n\x05price\x18\x01 \x01(\x04\x12\x16\n\x0emin_piece_size\x18\x02 \x01(\x04\x12\r\n\x05miner\x18\x03 \x01(\t\x12\x11\n\ttimestamp\x18\x04 \x01(\x03\x12\x0e\n\x06\x65xpiry\x18\x05 \x01(\x03\"\xba\x01\n\x05Index\x12\x14\n\x0clast_updated\x18\x01 \x01(\x03\x12\x1c\n\x14storage_median_price\x18\x02 \x01(\x04\x12\x32\n\x07storage\x18\x03 \x03(\x0b\x32!.index.ask.rpc.Index.StorageEntry\x1aI\n\x0cStorageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.index.ask.rpc.StorageAsk:\x02\x38\x01\"\x0c\n\nGetRequest\"2\n\x0bGetResponse\x12#\n\x05index\x18\x01 \x01(\x0b\x32\x14.index.ask.rpc.Index\"3\n\x0cQueryRequest\x12#\n\x05query\x18\x01 \x01(\x0b\x32\x14.index.ask.rpc.Query\"8\n\rQueryResponse\x12\'\n\x04\x61sks\x18\x01 \x03(\x0b\x32\x19.index.ask.rpc.StorageAsk2\x92\x01\n\nRPCService\x12>\n\x03Get\x12\x19.index.ask.rpc.GetRequest\x1a\x1a.index.ask.rpc.GetResponse\"\x00\x12\x44\n\x05Query\x12\x1b.index.ask.rpc.QueryRequest\x1a\x1c.index.ask.rpc.QueryResponse\"\x00\x42.Z,github.com/textileio/powergate/index/ask/rpcb\x06proto3'
)




_QUERY = _descriptor.Descriptor(
  name='Query',
  full_name='index.ask.rpc.Query',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_price', full_name='index.ask.rpc.Query.max_price', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='piece_size', full_name='index.ask.rpc.Query.piece_size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='index.ask.rpc.Query.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='index.ask.rpc.Query.offset', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=119,
)


_STORAGEASK = _descriptor.Descriptor(
  name='StorageAsk',
  full_name='index.ask.rpc.StorageAsk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='index.ask.rpc.StorageAsk.price', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_piece_size', full_name='index.ask.rpc.StorageAsk.min_piece_size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='miner', full_name='index.ask.rpc.StorageAsk.miner', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='index.ask.rpc.StorageAsk.timestamp', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='index.ask.rpc.StorageAsk.expiry', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=222,
)


_INDEX_STORAGEENTRY = _descriptor.Descriptor(
  name='StorageEntry',
  full_name='index.ask.rpc.Index.StorageEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='index.ask.rpc.Index.StorageEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='index.ask.rpc.Index.StorageEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=411,
)

_INDEX = _descriptor.Descriptor(
  name='Index',
  full_name='index.ask.rpc.Index',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='index.ask.rpc.Index.last_updated', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_median_price', full_name='index.ask.rpc.Index.storage_median_price', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage', full_name='index.ask.rpc.Index.storage', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_INDEX_STORAGEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=411,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='index.ask.rpc.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=413,
  serialized_end=425,
)


_GETRESPONSE = _descriptor.Descriptor(
  name='GetResponse',
  full_name='index.ask.rpc.GetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='index.ask.rpc.GetResponse.index', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=477,
)


_QUERYREQUEST = _descriptor.Descriptor(
  name='QueryRequest',
  full_name='index.ask.rpc.QueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='index.ask.rpc.QueryRequest.query', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=479,
  serialized_end=530,
)


_QUERYRESPONSE = _descriptor.Descriptor(
  name='QueryResponse',
  full_name='index.ask.rpc.QueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='asks', full_name='index.ask.rpc.QueryResponse.asks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=532,
  serialized_end=588,
)

_INDEX_STORAGEENTRY.fields_by_name['value'].message_type = _STORAGEASK
_INDEX_STORAGEENTRY.containing_type = _INDEX
_INDEX.fields_by_name['storage'].message_type = _INDEX_STORAGEENTRY
_GETRESPONSE.fields_by_name['index'].message_type = _INDEX
_QUERYREQUEST.fields_by_name['query'].message_type = _QUERY
_QUERYRESPONSE.fields_by_name['asks'].message_type = _STORAGEASK
DESCRIPTOR.message_types_by_name['Query'] = _QUERY
DESCRIPTOR.message_types_by_name['StorageAsk'] = _STORAGEASK
DESCRIPTOR.message_types_by_name['Index'] = _INDEX
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetResponse'] = _GETRESPONSE
DESCRIPTOR.message_types_by_name['QueryRequest'] = _QUERYREQUEST
DESCRIPTOR.message_types_by_name['QueryResponse'] = _QUERYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Query = _reflection.GeneratedProtocolMessageType('Query', (_message.Message,), {
  'DESCRIPTOR' : _QUERY,
  '__module__' : 'index.ask.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.ask.rpc.Query)
  })
_sym_db.RegisterMessage(Query)

StorageAsk = _reflection.GeneratedProtocolMessageType('StorageAsk', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEASK,
  '__module__' : 'index.ask.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.ask.rpc.StorageAsk)
  })
_sym_db.RegisterMessage(StorageAsk)

Index = _reflection.GeneratedProtocolMessageType('Index', (_message.Message,), {

  'StorageEntry' : _reflection.GeneratedProtocolMessageType('StorageEntry', (_message.Message,), {
    'DESCRIPTOR' : _INDEX_STORAGEENTRY,
    '__module__' : 'index.ask.rpc.rpc_pb2'
    # @@protoc_insertion_point(class_scope:index.ask.rpc.Index.StorageEntry)
    })
  ,
  'DESCRIPTOR' : _INDEX,
  '__module__' : 'index.ask.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.ask.rpc.Index)
  })
_sym_db.RegisterMessage(Index)
_sym_db.RegisterMessage(Index.StorageEntry)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREQUEST,
  '__module__' : 'index.ask.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.ask.rpc.GetRequest)
  })
_sym_db.RegisterMessage(GetRequest)

GetResponse = _reflection.GeneratedProtocolMessageType('GetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRESPONSE,
  '__module__' : 'index.ask.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.ask.rpc.GetResponse)
  })
_sym_db.RegisterMessage(GetResponse)

QueryRequest = _reflection.GeneratedProtocolMessageType('QueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUEST,
  '__module__' : 'index.ask.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.ask.rpc.QueryRequest)
  })
_sym_db.RegisterMessage(QueryRequest)

QueryResponse = _reflection.GeneratedProtocolMessageType('QueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRESPONSE,
  '__module__' : 'index.ask.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.ask.rpc.QueryResponse)
  })
_sym_db.RegisterMessage(QueryResponse)


DESCRIPTOR._options = None
_INDEX_STORAGEENTRY._options = None

_RPCSERVICE = _descriptor.ServiceDescriptor(
  name='RPCService',
  full_name='index.ask.rpc.RPCService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=591,
  serialized_end=737,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='index.ask.rpc.RPCService.Get',
    index=0,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Query',
    full_name='index.ask.rpc.RPCService.Query',
    index=1,
    containing_service=None,
    input_type=_QUERYREQUEST,
    output_type=_QUERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RPCSERVICE)

DESCRIPTOR.services_by_name['RPCService'] = _RPCSERVICE

# @@protoc_insertion_point(module_scope)
